<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="vi" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Đóng lại (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Xổ xuống</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Mở rộng</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Bỏ qua cảnh báo</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation type="unfinished">(Chưa đặt tiêu đề %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Rất tiếc</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Không thể lưu &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Lưu tập tin thành</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Không thể ghi đè lên &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Đổi tên tập tin</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Không thể đổi tên &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Tất cả các thay đổi chưa lưu sẽ bị mất.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Tải lại</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation type="unfinished">Chưa đặt tiêu đề %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Lưu dưới dạng văn bản thông thường sẽ bỏ qua tất cả các chỉnh sửa về hiển thị. Bỏ qua toàn bộ các hiển thị?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Đã thay đổi tập tin</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Bạn có muốn tải lại tập tin?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Tải lại</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Bỏ qua</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Đã xóa tập tin</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>Tập tin %1 đã bị xóa bởi một ứng dụng khác.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Bạn có muốn lưu hoặc đóng lại tập tin này?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation type="unfinished">Không thể mở phần lưu trữ.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Tìm kiếm cho:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Thay thế với:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Bỏ qua trường hợp chữ in hoa</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Chỉ toàn bộ các từ này</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Phép toán thông thường</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Tìm kiếm phía trên</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Tìm kiếm phía dưới</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Tìm kiếm</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>Th&amp;ay thế</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Tha&amp;y thế tất cả</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Tìm</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Thay thế</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Thay thế %n tiến trình?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Rất tiếc</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>Không tìm thấy cụm từ.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Thêm</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Kiểm tra lỗi chính tả...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Không tìm thấy lời đề nghị nào)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Mở hình ảnh</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Hình ảnh</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Chọn ngôn ngữ của ứng dụng:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Ngôn ngữ Hệ thống&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Ghi chú</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Xin vui lòng khởi động lại ứng dụng này để áp dụng thao tác thay đổi ngôn ngữ.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation type="unfinished">Không thể mở phần lưu trữ.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Tùy biến</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Tổng quan</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Thống kê</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Thanh công cụ</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Đang kiểm tra lỗi chính tả</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Chọn Từ Điển</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Rất tiếc</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Không thể mở phần lưu trữ.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>Phần lưu trữ không chứa từ điển nào có thể sử dụng được.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Phím tắt</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Một hoặc nhiều phím tắt hơn bị xung đột. Bạn có muốn tiếp tục?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Từ điển &quot;%1&quot; đã có sẵn. Bạn có muốn thay thế từ điển này không?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Mục tiêu mỗi ngày</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Không</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Phút:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Từ:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Đang chỉnh sửa</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Vị trí luôn thẳng đứng ở giữa</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Khóa việc chèn con trỏ</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Kiểu chữ dễ nhìn</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Âm thanh đánh máy khi gõ</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Trích dẫn thông minh:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Gấp đôi</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Đơn lẻ</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Khung cảnh</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Người chia cắt:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Đang lưu</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Nhớ vị trí trỏ chuột</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Tổng số từ</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Tổng số trang</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Tổng số đoạn văn</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Tổng số ký tự</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Ký tự:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Đoạn văn:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Thuật toán tính toán tổng số chữ</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Phát hiện việc bo tròn các chữ</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Chia các ký tự bởi nhóm có số lượng sáu</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Giao diện</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Chỉ hiển thị biểu tượng</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Chỉ hiển thị chữ</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Chữ kèm theo biểu tượng</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Chữ dưới biểu tượng</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Vị trí chữ:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Thao tác</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Di chuyển lên</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Di chuyển xuống</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Thêm dấu phân cách</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Lệnh</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Phím tắt</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Thao tác</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Kiểm tra ngữ pháp khi gõ</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Bỏ qua các từ IN HOA</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Bỏ qua các từ kèm theo số</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Ngôn ngữ</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Thêm</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Loại bỏ</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Từ điển tự tạo</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Down</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Chuyển cảnh lên</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Up</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Chuyển đổi danh sách các cảnh</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Hiển thị danh sách cảnh (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Ẩn danh sách cảnh (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Lọc dữ liệu</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Chuyển cảnh xuống</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Chỉnh lại kích thước danh sách cảnh</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Mặc định</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Quản lý phiên làm việc</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>P&amp;hiên làm việc</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Tạo mới</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Đổi tên</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Chuyển sang</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Phiên làm việc mới</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Đổi tên phiên làm việc</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Xóa phiên làm việc đã được chọn?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Tên phiên làm việc:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Rất tiếc</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>Tên của phiên làm việc được yêu cầu hiện đang được sử dụng.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Tạo mới...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Quản lý...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Dọn dẹp</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Chuyển về mặc định</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Phím tắt:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Thay đổi các phần đánh dấu trích dẫn..</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Vui lòng đợi</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Kiểm tra ngữ pháp</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Thêm</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Bỏ qua</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Bỏ q&amp;ua tất cả</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>Th&amp;ay đổi</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Tha&amp;y đổi tất cả</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Không có trong từ điển:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Thay đổi sang:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Đang thực hiện việc kiểm tra ngữ pháp...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Hủy bỏ</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Vui lòng đợi</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Đã thực hiện xong thao tác kiểm tra ngữ pháp.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Biểu tượng</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Các biểu tượng được dùng gần đây</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Tất cả biểu tượng</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Chi tiết</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Tên:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Chèn</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Khối</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Kịch bản</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Chưa đặt tiêu đề %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Tên:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Không có hình ảnh</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Xếp theo ô</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Ở giữa</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Trải rộng ra</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Theo tỉ lệ</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Phóng to</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Position:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Margins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Above:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Below:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Loại bỏ</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Loại:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Màu:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Hình ảnh:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation>điểm ảnh</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Bên tay trái</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Bên tay phải</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Văn bản</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Kiểu chữ:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Sai ngữ pháp:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Khoảng trống giữa các dòng</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Đơn lẻ</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1.5 dòng</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Gấp đôi</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Tỉ lệ cân xứng</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Khoảng cách giữa các đoạn văn</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Giao diện</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">Mặc định</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Old School</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Tạo mới</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished">Chỉnh sửa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Xóa</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Nhập dữ liệu</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Xuất dữ liệu</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Nhập dữ liệu về giao diện</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Xuất dữ liệu về giao diện</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Xóa phần đếm thời gian?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Số lượng từ:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Số lượng trang:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Số lượng đoạn văn:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Số lượng ký tự:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Đặt độ trễ</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Đặt thời gian</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Độ trễ:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Thời gian:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Hẹn giờ</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Loại:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Ghi chú:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Chỉnh sửa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Xóa</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Hiện không có phần đếm thời gian nào</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Bộ đếm thời gian</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Tạo mới</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Gần đây</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Câu hỏi</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Hủy bỏ việc chỉnh sửa bộ đếm giờ?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Đang tải dữ liệu giao diện</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Đang tải dữ liệu âm thanh</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Chưa đặt tiêu đề</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Mở tập tin</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Dịch bởi Phan Anh</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Một phần mềm soạn thảo văn bản toàn màn hình dạng đơn giản</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Bản quyền &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Phát hành dựa theo giấy phép &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Sử dụng bộ biểu tượng từ &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Sử dụng dựa trên giấy phép &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Số ký tự: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Số trang: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Số đoạn văn: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Số từ: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Đang mở %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Chưa đặt tiêu đề %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Chuyển sang một tài liệu mới</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Chuyển sang tài liệu trước đó</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Chuyển sang tài liệu đầu tiên</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Chuyển sang tài liệu cuối cùng</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Chuyển sang tài liệu %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Đang tải thiết lập</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Phần bộ nhớ đệm trong trường hợp khẩn cấp hiện không thể ghi dữ liệu vào.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Cảnh báo</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter đã không được tắt theo đúng cách.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Khôi phục dữ liệu từ phần bộ nhớ đệm khẩn cấp?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Không thể mở một số tập tin.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Một vài tập tin được mở dưới chế độ Chỉ Được-Đọc</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; mới hơn bản dữ liệu được sao chép trong bộ nhớ đệm.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Viết đè dữ liệu lên tập tin mới hơn?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Không thể tải âm thanh tạo hiệu ứng gõ chữ.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Tập tin</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Tạo mới</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Mở...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Tải l&amp;ại</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Lưu</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Lưu &amp;Dưới Dạng...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Đổi tên...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Lưu T&amp;ất Cả</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Quản lý phiên làm việc</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Phiên làm việc mới</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;In dữ liệu...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Đ&amp;óng lại</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Th&amp;oát</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>C&amp;hỉnh sửa</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>Hủ&amp;y thao tác</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Lặ&amp;p lại thao tác</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Cắ&amp;t</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>S&amp;ao chép</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>D&amp;án</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Dán vào dữ liệu ch&amp;ưa chỉnh sửa</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Chọn tấ&amp;t cả</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Chọn c&amp;ảnh</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Đị&amp;nh dạng</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;In đậm</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>I&amp;n nghiêng</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Gạch dưới</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>G&amp;ạch xuyên qua</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Chữ t&amp;rồi lên</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Chữ s&amp;ụp xuống</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Canh lề b&amp;ên trái</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Canh lề c&amp;hính giữa</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Canh lề bên p&amp;hải</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>Canh lề đ&amp;ều hai bên</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>Giả&amp;m mức lùi dòng</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>Tă&amp;ng mức lùi dòng</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>Khối văn bản từ tr&amp;ái sang phải</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Khối văn bản từ ph&amp;ải sang trái</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Cô&amp;ng cụ</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>Tì&amp;m kiếm...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Tìm tiế&amp;p theo</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Tìm tr&amp;ước đó</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>Th&amp;ay thế...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>Trích dẫn thô&amp;ng minh:</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Cập nhật tà&amp;i liệu</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Cập nhật v&amp;ùng lựa chọn</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>Kiểm tr&amp;a lỗi chính tả...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>B&amp;ộ đếm thời gian</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Biể&amp;u tượng...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>Thiế&amp;t lập</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Hiển thị th&amp;anh công cụ</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>Hiển thị biểu tượng men&amp;u</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Tập tr&amp;ung vào văn bản</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>Toàn mà&amp;n hình</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>T&amp;hu nhỏ</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>G&amp;iao diện...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>Tùy biế&amp;n...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Tắt phần tập trung</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Tập trung vào một dòng văn bản</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Tập trung vào ba dòng văn bản</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Đoạn văn</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Tập trung vào đoạn văn</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Dịch bởi P&amp;han Anh</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Ngôn ngữ hiển th&amp;ị...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Một số tập tin không được hỗ trợ nên sẽ không thể mở được.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>T&amp;ắt</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Một D&amp;òng</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>B&amp;a Dòng</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>Thô&amp;ng tin</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Thô&amp;ng tin về Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
